@@ -83,6 +83,8 @@ struct mythtvfs {
     int short_display_flag;
     int backend_version_override; // manually override compile-time defaults
     int program_width_override;   // manually override compile-time defaults
+    char * invalid_chars;         // list of invalid characters
+    char * replacement_char;      // character to replace invalid chars with
     char * logfile_name;
 
     /* runtime state trackers */
@@ -104,6 +106,8 @@ static struct fuse_opt mythtvfs_opts[] = {
     MYTHTVFS_OPT("logfile=%s",         logfile_name, 0),
     MYTHTVFS_OPT("backend-version=%d", backend_version_override, 0),
     MYTHTVFS_OPT("program-width=%d",   program_width_override, 0),
+    MYTHTVFS_OPT("invalid-chars=%s",   invalid_chars, 0),
+    MYTHTVFS_OPT("replacement-char=%s",replacement_char, 0),
   
     FUSE_OPT_KEY("-V",                KEY_VERSION),
     FUSE_OPT_KEY("--version",         KEY_VERSION),
@@ -129,6 +133,8 @@ static void usage(const char *progname)
         "    -o logfile=FILE       write verbose logging to FILE\n"
         "    -o backend-version=N  override compile-time backend version\n"
         "    -o program-width=N    override compile-time program width\n"
+        "    -o invalid-chars=STR  list of characters not allowed in filenames\n"
+        "    -o replacement-char=C character to replace invalid characters with\n"
         "\n",progname);
 }
 
@@ -678,8 +684,11 @@ static int mythtvfs_readdir(const char *path, void *buf, fuse_fill_dir_t filler,
                      filename);
         }
 
-        // filter "/" out of metaname
-        for (ptr = metaname; *ptr; ptr++) { if (*ptr == '/') *ptr='-'; }
+        // filter out invalid characters
+        for (ptr = metaname; *ptr; ptr++) {
+            if (*ptr == '/' || strchr(mythtvfs.invalid_chars,*ptr))
+                *ptr=*mythtvfs.replacement_char;
+        }
 
         st.st_ino++;
         st.st_mode = S_IFREG|S_IRUSR|S_IRGRP|S_IROTH;
@@ -1111,6 +1120,8 @@ int main(int argc, char *argv[])
     mythtvfs.short_display_flag = 0;
     mythtvfs.backend_version_override = 0;
     mythtvfs.program_width_override = 0;
+    mythtvfs.invalid_chars = strdup("/");
+    mythtvfs.replacement_char = strdup("-");
     mythtvfs.backend   = -1;
     mythtvfs.base_len  = 0;
     mythtvfs.logfile   = NULL;
